@@ -40,10 +40,15 @@ summary.mirtCAT <- function(object, sort = TRUE, ...){
         ret$item_time <- object$item_time[pick]
     if(length(ret$thetas_history) == 1L || is.na(ret$thetas_history))
         ret$thetas_history <- ret$thetas_SE_history <- NULL
-    if(all(ret$raw_responses == ret$responses, na.rm = TRUE))
+    if(all(ret$raw_responses == ret$responses, na.rm = TRUE) || 
+           all((ret$raw_responses-1L) == ret$responses, na.rm = TRUE))
         ret$raw_responses <- NULL
     if(!length(object$demographics))
         ret$demographics <- NULL
+    if(!is.null(object$classification)){
+        ret$classification <- as.character(object$classification)
+        names(ret$classification) <- colnames(ret$thetas_history)
+    }
     ret
 }
 
@@ -56,7 +61,7 @@ summary.mirtCAT <- function(object, sort = TRUE, ...){
 #'   \code{'CAT ##\% Confidence Intervals'} depending on the SE input
 #' @param SE size of the standard errors to plot. The default is 1, and therefore plots the
 #'   standard error. To obtain the 95\% interval use \code{SE = 1.96} (from the z-distribution)
-#' @param ... additional arguments to be passed to \code{lattice}
+#' @param ... additional arguments to be passed to \code{lattice} or \code{fscores}
 #' @export
 plot.mirtCAT <- function(x, pick_theta = NULL, SE = 1, main = NULL, ...){
     if(length(x$thetas_SE_history) == 1L || is.na(x$thetas_SE_history))
